pub fn cert_bytes(cert: &DelegationCert) -> Result<Vec<u8>, CanonicalAuthError>Expand description
Encode a certificate without changing grant order or normalizing labels.
pub fn cert_bytes(cert: &DelegationCert) -> Result<Vec<u8>, CanonicalAuthError>Encode a certificate without changing grant order or normalizing labels.